@@ -107,7 +107,7 @@ impl Candlestick for FtxWSClient {
 
 panic_l3_orderbook!(FtxWSClient);
 
-define_client!(
+impl_new_constructor!(
     FtxWSClient,
     EXCHANGE_NAME,
     WEBSOCKET_URL,
@@ -116,3 +116,4 @@ define_client!(
     Some(CLIENT_PING_INTERVAL_AND_MSG),
     None
 );
+impl_ws_client_trait!(FtxWSClient);
